% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_functions.R
\name{KBO_known}
\alias{KBO_known}
\title{KBO_known a function to calculate a likelihood on given parameters}
\usage{
KBO_known(param, threshold, kappa = 10, Y, Tps, N)
}
\arguments{
\item{param}{list, a list of 10 input parameters for mm, pp and m0}

\item{threshold}{numeric, threshold for CI, default 0.5}

\item{kappa}{numeric, truncation setting, default 10}

\item{Y}{character, name of the numeric variable to predict in the
data.frame datain}

\item{Tps}{character, time column name in the data.frame datain, a 
numeric vector.
Tvar can be expressed as a proportion of day in seconds}

\item{N}{numeric, length of Y}
}
\value{
a list
\describe{
 \item{prediction}{vector, the prediction of weights}
 \item{label}{vector, probability to be an outlier}
 \item{likelihood}{numeric, the calculated likelihood}
 \item{lwr}{vector of lower bound CI of the prediction }
 \item{upr}{vector of upper bound CI of the prediction }
 \item{flag}{char, is an outlier or not}
}
}
\description{
KBO_known a function to calculate a likelihood on given parameters
}
\details{
uses the same input parameter list than the main function
}
\examples{
set.seed(1234)
Y<-rnorm(n=10,mean=50,4)
Tps<-seq(1,10)
N=10
param2<-list(m0=41,
             mm=45,
             pp=0.5,
             aa=0.001,
             expertMin=30,
             expertMax=75,
             sigma2_m0=1,
             sigma2_mm=0.05,
             sigma2_pp=5,
             K=2,
            seqp=seq(0.5,0.7,0.1))
print(Y)
KBO_known(param=param2,threshold=0.5,kappa=10,Y=Y,Tps=Tps,N=N)
}
